﻿/* Title: CasWriter   
   Author: Matteo Slaviero 
   This work is absolutely free to use, copy, modify or redistribute for any purpose in any country. */

using System;
using System.Reflection;
using System.Text;
using System.Security;
using System.IO;

[assembly: AllowPartiallyTrustedCallers()]
namespace CasWriterDemo
{
    /// <summary>
    /// Write sentences
    /// </summary>
    public class CasWriter
    {
        /// <summary>
        /// Write a sentenct to console
        /// </summary>
        /// <param name="text"></param>
        [SecurityCritical()]
        public virtual void WriteCustomSentence(string text)
        {
            Console.WriteLine(text + "\n");
        }

        /// <summary>
        /// Write a sentenct to console
        /// </summary>
        /// <param name="text"></param>
         [SecuritySafeCritical()]
        public void WriteDefaultSentence(int index)
        {
            switch (index)
            { 
                case 0:
                    WriteCustomSentence("homo homini lupus");
                    break;
                case 1:
                    WriteCustomSentence("melius abundare quam deficere");
                    break;
                case 2:
                    WriteCustomSentence("audaces fortuna iuvat");
                    break;
            }
        }


        /// <summary>
        /// Get the Security status of each method developed
        /// </summary>
        public string GetMethodsSecurityStatus()
        {
            //get the MethodInfo of each method
            MethodInfo[] infos = GetType().GetMethods();

            StringBuilder sb = new StringBuilder();
            foreach (MethodInfo m in infos)
            {

                if (m.ReturnType != typeof(void)) continue;

                sb.Append("\n");
                sb.Append(m.Name + ": ");

                if (m.IsSecuritySafeCritical)
                {
                    sb.Append("SecuritySafeCritical\n");
                }
                else if (m.IsSecurityCritical)
                {
                    sb.Append("SecurityCritical\n");
                }
                else if (m.IsSecurityTransparent)
                {
                    sb.Append("SecurityTransparent\n");
                }
            }

            return sb.Append("\n\n").ToString();
        
        }
    }
}
